%define pypi_name Glances

Name:           glances
Version:        3.3.1
Release:        %mkrel 2
Group:          Monitoring
Summary:        A cross-platform curses-based monitoring tool

License:        LGPLv3
URL:            https://github.com/nicolargo/glances
Source0:        https://pypi.io/packages/source/G/Glances/%{pypi_name}-%{version}.tar.gz
Source1:        %{name}.service
Patch1:         disable-update-check.patch
BuildArch:      noarch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(psutil)
BuildRequires:  python3dist(ujson)

Requires:       python3-pkg-resources
Requires:       python3dist(ujson)
Recommends:     python3-bottle
Recommends:     python3-pysnmp
Recommends:     python3-sensors
Recommends:     python3-batinfo
Recommends:     hddtemp

%description
Glances is a CLI curses based monitoring tool for both GNU/Linux and BSD.
Glances uses the PsUtil library to get information from your system.
It is developed in Python.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files glances

install -D -p -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
# default config file, disables the online update check by default
install -D -p -m 644 conf/glances.conf %{buildroot}%{_sysconfdir}/glances/glances.conf

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files -f %{pyproject_files}
%doc AUTHORS README.rst
%license COPYING
%exclude %{_datadir}/doc/glances
%dir %{_sysconfdir}/glances
%config(noreplace) %{_sysconfdir}/glances/glances.conf
%{_bindir}/glances
%{_mandir}/man1/glances.1.*
%{_unitdir}/%{name}.service
# Remove a lot of JS/node.js/npm junk that slows down the packaging.
%exclude %{python3_sitelib}/%{name}/outputs/static


%changelog
* Mon Feb 13 2023 daviddavid <daviddavid> 3.3.1-2.mga9
+ Revision: 1941259
- add missing dependency on python3-ujson
- switch to pyproject
- add patch to disable default update check
- use upstream glances config file
- add from fedora systemd unit file

* Sun Feb 12 2023 mrambo3501 <mrambo3501> 3.3.1-1.mga9
+ Revision: 1941062
- verison 3.3.1

* Wed Mar 23 2022 umeabot <umeabot> 3.1.6.2-3.mga9
+ Revision: 1822399
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 3.1.6.2-2.mga9
+ Revision: 1773580
- Fix filelist for python-3.10
- Rebuild for python-3.10

* Sat Mar 27 2021 ovitters <ovitters> 3.1.6.2-1.mga9
+ Revision: 1711131
- new version 3.1.6.2

* Sat Mar 27 2021 ovitters <ovitters> 3.1.5-3.mga9
+ Revision: 1711130
- disable online update check by default

* Fri Mar 26 2021 ovitters <ovitters> 3.1.5-2.mga9
+ Revision: 1710479
- rebuild for Python 3.9

* Sun Aug 30 2020 shlomif <shlomif> 3.1.5-1.mga8
+ Revision: 1619736
- New version 3.1.5

* Fri Apr 24 2020 shlomif <shlomif> 3.1.4.1-1.mga8
+ Revision: 1571679
- New version 3.1.4.1

* Fri Mar 20 2020 shlomif <shlomif> 3.1.4-1.mga8
+ Revision: 1558284
- New version 3.1.4

* Tue Feb 18 2020 umeabot <umeabot> 3.1.3-2.mga8
+ Revision: 1541705
- Mageia 8 Mass Rebuild

* Tue Dec 31 2019 shlomif <shlomif> 3.1.3-1.mga8
+ Revision: 1475052
- New version 3.1.3
- New version 3.1.3, but it includes a lot of npm junk.

* Sat Sep 21 2019 daviddavid <daviddavid> 3.1.2-2.mga8
+ Revision: 1444270
- rebuild for python3.8

* Tue Sep 03 2019 shlomif <shlomif> 3.1.2-1.mga8
+ Revision: 1436829
- New version 3.1.2

* Mon Jul 29 2019 shlomif <shlomif> 3.1.1-1.mga8
+ Revision: 1424856
- New version 3.1.1

* Mon Jan 28 2019 shlomif <shlomif> 3.1.0-1.mga7
+ Revision: 1361624
- New version 3.1.0

* Tue Jan 08 2019 ovitters <ovitters> 3.0.2-2.mga7
+ Revision: 1352894
- rebuild for python3 3.7

* Sun Oct 14 2018 shlomif <shlomif> 3.0.2-1.mga7
+ Revision: 1320316
- New version 3.0.2

* Thu Sep 20 2018 umeabot <umeabot> 3.0.1-2.mga7
+ Revision: 1278412
- Mageia 7 Mass Rebuild

* Wed Sep 12 2018 shlomif <shlomif> 3.0.1-1.mga7
+ Revision: 1258680
- New version 3.0.1

* Mon Oct 30 2017 shlomif <shlomif> 2.11.1-1.mga7
+ Revision: 1174898
- New version 2.11.1

* Sat Aug 05 2017 pterjan <pterjan> 2.10-2.mga7
+ Revision: 1135218
- Rebuild for python 3.6

* Mon Jul 17 2017 shlomif <shlomif> 2.10-1.mga7
+ Revision: 1124458
- New version 2.10

* Sat Apr 16 2016 shlomif <shlomif> 2.6.1-1.mga6
+ Revision: 1002895
- New version 2.6.1

* Fri Feb 19 2016 umeabot <umeabot> 2.0-7.mga6
+ Revision: 970508
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 ovitters <ovitters> 2.0-6.mga6
+ Revision: 887047
- rebuild for new python3

* Wed Oct 15 2014 umeabot <umeabot> 2.0-5.mga5
+ Revision: 742573
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.0-4.mga5
+ Revision: 726349
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0-3.mga5
+ Revision: 679611
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Fri Jun 20 2014 ovitters <ovitters> 2.0-2.mga5
+ Revision: 638184
- require python3-pkg-resources

* Thu Jun 19 2014 philippem <philippem> 2.0-1.mga5
+ Revision: 638178
- update to 2.0, use Python3

* Sat May 31 2014 pterjan <pterjan> 1.7.6-2.mga5
+ Revision: 628221
- Rebuild for new Python

* Mon Mar 31 2014 kharec <kharec> 1.7.6-1.mga5
+ Revision: 610895
- new version 1.7.6

* Mon Mar 24 2014 kharec <kharec> 1.7.5-1.mga5
+ Revision: 608178
- fix group
- imported package glances

